@@ -1,7 +1,7 @@
 package App::metasyn;
 
-our $DATE = '2021-02-21'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $DATE = '2021-03-03'; # DATE
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict;
@@ -26,9 +26,17 @@ $SPEC{metasyn} = {
     summary => 'Alternative front-end to Acme::MetaSyntactic',
     description => <<'_',
 
-This script is an alternative front-end to <pm:Acme::MetaSyntactic>. Compared to
-the official CLI <prog:meta>, this CLI is more oriented towards listing names
-instead of giving you one or several random names.
+This script is an alternative front-end for <pm:Acme::MetaSyntactic>. Compared
+to the official CLI <prog:meta>, this CLI currently does not retrieve
+themes/names remotely but:
+
+* provides shell completion;
+* provides an option to shuffle list of themes/categories/names returned;
+* makes it easy to print all names in a theme;
+* makes it easy to print all (or some) categories in a theme.
+
+This CLI is more geared towards listing all themes/names/categories instead of
+picking one.
 
 _
     args => {
@@ -48,7 +56,12 @@ _
             },
         },
         shuffle => {
-            schema => ['bool*', is=>1],
+            schema => 'true*',
+            cmdline_aliases => {R=>{}},
+        },
+        random_theme => {
+            schema => 'true*',
+            cmdline_aliases => {T=>{}},
         },
         number => {
             summary => 'Limit only return this number of results',
@@ -56,40 +69,66 @@ _
             cmdline_aliases => {n=>{}},
         },
         categories => {
-            schema => ['bool*', is=>1],
+            schema => 'true*',
             cmdline_aliases => {c=>{}},
         },
     },
     examples => [
+        # listing names
         {
-            summary => 'List all installed themes',
+            summary => 'List all names from the default theme, foo',
+            argv => [qw//],
+            'x.doc.max_result_lines' => 10,
+        },
+        {
+            summary => 'Return a single random name from the default theme (equivalent of: meta)',
+            argv => [qw/-n1 -R/],
+        },
+        {
+            summary => 'List all names from a theme',
+            argv => [qw/christmas/],
+            'x.doc.max_result_lines' => 10,
+        },
+        {
+            summary => 'List all names from a category of a theme in random order, return only 3 (equivalent of: meta christmas/elf 3)',
+            argv => [qw(christmas/elf -n3 -R)],
+        },
+        {
+            summary => 'Return a single random name from a theme (equivalent of: meta christmas)',
+            argv => [qw(christmas -n1 -R)],
+        },
+        {
+            summary => 'Return a single random name from a random theme',
+            argv => [qw(-T -n1 -R)],
+        },
+
+        # listing themes
+        {
+            summary => 'List all installed themes (equivalent of: meta --themes)',
             argv => [qw/-l/],
             'x.doc.max_result_lines' => 10,
         },
         {
-            summary => 'List 3 random themes',
-            argv => [qw/-l -n3 --shuffle/],
+            summary => 'List 3 random themes (equivalent of: meta --themes | shuf | head -n3)',
+            argv => [qw/-l -n3 -R/],
         },
         {
             summary => 'List all installed themes, along with all their categories',
             argv => [qw/-l -c/],
             'x.doc.max_result_lines' => 10,
         },
-        {
-            summary => 'List all names from a theme',
-            argv => [qw/foo/],
-            'x.doc.max_result_lines' => 10,
-        },
-        {
-            summary => 'List all names from a theme in random order, return only 3',
-            argv => [qw(christmas/elf -n3 --shuffle)],
-            'x.doc.max_result_lines' => 10,
-        },
+
+        # listing categories
         {
             summary => 'List all categories from a theme',
             argv => [qw(christmas -c)],
             'x.doc.max_result_lines' => 10,
         },
+        {
+            summary => 'List 2 categories from a theme, in random order',
+            argv => [qw(christmas -c -n2 -R)],
+            'x.doc.max_result_lines' => 10,
+        },
     ],
     links => [
         {url=>'prog:meta'},
@@ -125,8 +164,15 @@ sub metasyn {
         return [200, "OK", _shuffle_and_limit(\@res, \%args)];
     }
 
-    my $theme = $args{theme};
-    return [400, "Please specify theme"] unless $theme;
+    my $theme;
+    if ($args{theme}) {
+        $theme = $args{theme};
+    } elsif ($args{random_theme}) {
+        my @themes = Acme::MetaSyntactic->new->themes;
+        $theme = $themes[rand @themes];
+    } else {
+        $theme = 'foo';
+    }
     my $cat = $theme =~ s{/(.+)\z}{} ? $1 : undef;
 
     my $pkg = "Acme::MetaSyntactic::$theme";
@@ -168,7 +214,7 @@ App::metasyn - Alternative front-end to Acme::MetaSyntactic
 
 =head1 VERSION
 
-This document describes version 0.006 of App::metasyn (from Perl distribution App-metasyn), released on 2021-02-21.
+This document describes version 0.007 of App::metasyn (from Perl distribution App-metasyn), released on 2021-03-03.
 
 =head1 SYNOPSIS
 
@@ -189,70 +235,9 @@ Examples:
 
 =over
 
-=item * List all installed themes:
+=item * List all names from the default theme, foo:
 
- metasyn( action => "list-themes");
-
-Result:
-
- [
-   200,
-   "OK",
-   [
-     "abba",
-     "afke",
-     "alice",
-     "alphabet",
- # ...snipped 137 lines for brevity...
-     "viclones",
-     "wales_towns",
-     "weekdays",
-     "yapc",
-     "zodiac",
-   ],
-   {},
- ]
-
-=item * List 3 random themes:
-
- metasyn( action => "list-themes", number => 3, shuffle => 1);
-
-Result:
-
- [
-   200,
-   "OK",
-   ["display_resolution", "loremipsum", "jabberwocky"],
-   {},
- ]
-
-=item * List all installed themes, along with all their categories:
-
- metasyn( action => "list-themes", categories => 1);
-
-Result:
-
- [
-   200,
-   "OK",
-   [
-     "abba",
-     "afke",
-     "alice",
-     "alphabet/en",
- # ...snipped 2209 lines for brevity...
-     "zodiac/Chinese",
-     "zodiac/Vedic",
-     "zodiac/Western",
-     "zodiac/Western/Real",
-     "zodiac/Western/Traditional",
-   ],
-   {},
- ]
-
-=item * List all names from a theme:
-
- metasyn( theme => "foo");
+ metasyn();
 
 Result:
 
@@ -274,13 +259,105 @@ Result:
    {},
  ]
 
-=item * List all names from a theme in random order, return only 3:
+=item * Return a single random name from the default theme (equivalent of: meta):
+
+ metasyn( number => 1, shuffle => 1); # -> [200, "OK", ["kees"], {}]
+
+=item * List all names from a theme:
+
+ metasyn( theme => "christmas");
+
+Result:
+
+ [
+   200,
+   "OK",
+   [
+     "bushy",
+     "evergreen",
+     "shinny",
+     "upatree",
+ # ...snipped 59 lines for brevity...
+     "mcsnowballs",
+     "mcicicles",
+     "mcblizzard",
+     "mcsparkles",
+     "mcsnowflakes",
+   ],
+   {},
+ ]
+
+=item * List all names from a category of a theme in random order, return only 3 (equivalent of: meta christmasE<sol>elf 3):
 
  metasyn( theme => "christmas/elf", number => 3, shuffle => 1);
 
 Result:
 
- [200, "OK", ["opneslae", "minstix", "snowball"], {}]
+ [200, "OK", ["bushy", "snowball", "wunorse"], {}]
+
+=item * Return a single random name from a theme (equivalent of: meta christmas):
+
+ metasyn( theme => "christmas", number => 1, shuffle => 1); # -> [200, "OK", ["donner"], {}]
+
+=item * Return a single random name from a random theme:
+
+ metasyn( number => 1, random_theme => 1, shuffle => 1); # -> [200, "OK", ["meu"], {}]
+
+=item * List all installed themes (equivalent of: meta --themes):
+
+ metasyn( action => "list-themes");
+
+Result:
+
+ [
+   200,
+   "OK",
+   [
+     "abba",
+     "afke",
+     "alice",
+     "alphabet",
+ # ...snipped 138 lines for brevity...
+     "viclones",
+     "wales_towns",
+     "weekdays",
+     "yapc",
+     "zodiac",
+   ],
+   {},
+ ]
+
+=item * List 3 random themes (equivalent of: meta --themes E<verbar> shuf E<verbar> head -n3):
+
+ metasyn( action => "list-themes", number => 3, shuffle => 1);
+
+Result:
+
+ [200, "OK", ["contrade", "display_resolution", "tld"], {}]
+
+=item * List all installed themes, along with all their categories:
+
+ metasyn( action => "list-themes", categories => 1);
+
+Result:
+
+ [
+   200,
+   "OK",
+   [
+     "abba",
+     "afke",
+     "alice",
+     "alphabet/en",
+ # ...snipped 2211 lines for brevity...
+     "zodiac/Chinese",
+     "zodiac/Vedic",
+     "zodiac/Western",
+     "zodiac/Western/Real",
+     "zodiac/Western/Traditional",
+   ],
+   {},
+ ]
 
 =item * List all categories from a theme:
 
@@ -290,11 +367,34 @@ Result:
 
  [200, "OK", ["elf", "reindeer", "santa", "snowman"], {}]
 
+=item * List 2 categories from a theme, in random order:
+
+ metasyn( theme => "christmas", categories => 1, number => 2, shuffle => 1);
+
+Result:
+
+ [200, "OK", ["snowman", "santa"], {}]
+
 =back
 
-This script is an alternative front-end to L<Acme::MetaSyntactic>. Compared to
-the official CLI L<meta>, this CLI is more oriented towards listing names
-instead of giving you one or several random names.
+This script is an alternative front-end for L<Acme::MetaSyntactic>. Compared
+to the official CLI L<meta>, this CLI currently does not retrieve
+themes/names remotely but:
+
+=over
+
+=item * provides shell completion;
+
+=item * provides an option to shuffle list of themes/categories/names returned;
+
+=item * makes it easy to print all names in a theme;
+
+=item * makes it easy to print all (or some) categories in a theme.
+
+=back
+
+This CLI is more geared towards listing all themes/names/categories instead of
+picking one.
 
 This function is not exported.
 
@@ -304,13 +404,15 @@ Arguments ('*' denotes required arguments):
 
 =item * B<action> => I<str> (default: "list-names")
 
-=item * B<categories> => I<bool>
+=item * B<categories> => I<true>
 
 =item * B<number> => I<posint>
 
 Limit only return this number of results.
 
-=item * B<shuffle> => I<bool>
+=item * B<random_theme> => I<true>
+
+=item * B<shuffle> => I<true>
 
 =item * B<theme> => I<str>
 
